lib

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 10, 2023 License: MIT Imports: 8 Imported by: 0

README

Digital Commons BePress API

Based off the API documentation fonud here: https://bepress.com/wp-content/uploads/2020/05/Real-time-API-documentation.pdf

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewDigitalCommonsAPI added in v0.1.0

func NewDigitalCommonsAPI(siteURL string, securityToken string) *digitalCommonsAPI

NewDigitalCommonsAPI creates a new instance of the DigitalCommonsAPI client.

Types

type ExportID added in v0.1.0

type ExportID struct {
	ExportId string `json:"ExportId"`
}

ExportID represents the export ID returned by the PUT request to the export endpoint.

type QueryParameters added in v0.1.0

type QueryParameters struct {
	Q               string
	Abstract        string
	Author          string
	PublicationYear string
	ParentLink      string
	Fields          string
	SelectFields    string
	Limit           string
	Start           string
}

represent optional url query paramters than can be added into the query q - the query string abstract - a string that is contained in the abstract author - a string that is contained in the author name publication_year - a year (YYYY) that is contained in the publication date parent_link - Retrieve all items in a publication context like a series or journal, using the full publication URL as a filter. For example, The format of a query that would return metadata for items in a collection is https://content-out.bepress.com/v2/{site_url}/query?parent_link=http://{site_url}/{publication} fields - If you would like to have a specific set of metadata fields returned, use the “fields” parameter. For example, this query for 'water' would return only the url, title, abstract, and autor of each hit. https://content-out.bepress.com/v2/{site_url}/query?q=water&fields=url,title,abstract,author select_fields - If you would like to return all available metadata fields, use select_fields=all. Keep in mind that `select_fields` and `fields` are mutually exclusive. If you use both, `fields` will be ignored. limit - Specifies how many results each page should contain; 100 results are returned by default. The limit can be set from 1 to 1000 results per page. start - Specifies from which result the page should start; the default value is 0.

Jump to